@@ -25,7 +25,7 @@ from collections.abc import Iterable
 
 import numpy as np
 import sympy
-from mgetool.tool import parallelize
+from mgetool.tool import parallelize, batch_parallelize
 from sklearn.metrics import r2_score
 from sklearn.utils import check_X_y, check_array
 
@@ -820,11 +820,11 @@ class SymbolSet(object):
         n = X.shape[1]
         self.y = y.ravel()
 
-        if y_dim is 1:
+        if y_dim == 1:
             y_dim = dless
         self.y_dim = y_dim
 
-        if x_dim is 1:
+        if x_dim == 1:
             x_dim = [dless for _ in range(n)]
 
         if x_prob is None:
@@ -906,7 +906,7 @@ class SymbolSet(object):
 
         n = len(c)
 
-        if c_dim is 1:
+        if c_dim == 1:
             c_dim = [dless for _ in range(n)]
 
         if c_prob is None:
@@ -1308,7 +1308,7 @@ class CalculatePrecisionSet(SymbolSet):
     def __init__(self, pset, scoring=None, score_pen=(1,), filter_warning=True, cv=1,
                  cal_dim=True, dim_type=None, fuzzy=False, add_coef=True, inter_add=True,
                  inner_add=False, vector_add=False, out_add=False, flat_add=False, n_jobs=1, batch_size=20,
-                 tq=True, details=False, classification=False, score_object="y"):
+                 tq=True, details=False, classification=False, score_object="y", batch_para=False):
         """
 
         Parameters
@@ -1377,6 +1377,7 @@ class CalculatePrecisionSet(SymbolSet):
         self.flat_add = flat_add
         self.n_jobs = n_jobs
         self.batch_size = batch_size
+        self.batch_para = batch_para
         self.tq = tq
         self.fuzzy = fuzzy
         self.dim_type = dim_type if dim_type is not None else self.y_dim
@@ -1651,8 +1652,13 @@ class CalculatePrecisionSet(SymbolSet):
                                   details=self.details
                                   )
 
-        score_dim_list = parallelize(func=calls, iterable=indss, n_jobs=self.n_jobs,
-                                     respective=False,
-                                     tq=self.tq, batch_size=self.batch_size)
+        if isinstance(self.batch_size, int) and self.batch_para:
+            score_dim_list = batch_parallelize(func=calls, iterable=indss, n_jobs=self.n_jobs,
+                                               respective=False,
+                                               tq=self.tq, batch_size=self.batch_size)
+        else:
+            score_dim_list = parallelize(func=calls, iterable=indss, n_jobs=self.n_jobs,
+                                         respective=False,
+                                         tq=self.tq, batch_size=self.batch_size)
 
         return score_dim_list
